@@ -17,4 +17,13 @@ big.kronecker <- function(x,...){
 	x[[1]] <- kronecker(x[[1]],x[[2]],...)
 	x[[2]] <- NULL
 	Recall(x,...)
-}
\ No newline at end of file
+}
+
+
+
+# get the dimids from a data list
+#
+# used in: dims_to_vars
+#
+get.dimids <- function(dl)
+	attr(dl, "match.dimids")[[attr(dl, "bm")]]
